@@ -1,5 +1,6 @@
 """Tests for aiohttp/protocol.py"""
 
+import asyncio
 import zlib
 from unittest import mock
 
@@ -9,9 +10,12 @@ from yarl import URL
 
 import aiohttp
 from aiohttp import http_exceptions, streams
-from aiohttp.http_parser import (DeflateBuffer, HttpPayloadParser,
-                                 HttpRequestParserPy, HttpResponseParserPy)
-
+from aiohttp.http_parser import (
+    DeflateBuffer,
+    HttpPayloadParser,
+    HttpRequestParserPy,
+    HttpResponseParserPy,
+)
 
 try:
     import brotli
@@ -70,7 +74,7 @@ def stream():
     return mock.Mock()
 
 
-def test_parse_headers(parser):
+def test_parse_headers(parser) -> None:
     text = b'''GET /test HTTP/1.1\r
 test: line\r
  continue\r
@@ -90,7 +94,7 @@ test2: data\r
     assert not msg.upgrade
 
 
-def test_parse(parser):
+def test_parse(parser) -> None:
     text = b'GET /test HTTP/1.1\r\n\r\n'
     messages, upgrade, tail = parser.feed_data(text)
     assert len(messages) == 1
@@ -102,7 +106,7 @@ def test_parse(parser):
     assert msg.version == (1, 1)
 
 
-async def test_parse_body(parser):
+async def test_parse_body(parser) -> None:
     text = b'GET /test HTTP/1.1\r\nContent-Length: 4\r\n\r\nbody'
     messages, upgrade, tail = parser.feed_data(text)
     assert len(messages) == 1
@@ -111,7 +115,7 @@ async def test_parse_body(parser):
     assert body == b'body'
 
 
-async def test_parse_body_with_CRLF(parser):
+async def test_parse_body_with_CRLF(parser) -> None:
     text = b'\r\nGET /test HTTP/1.1\r\nContent-Length: 4\r\n\r\nbody'
     messages, upgrade, tail = parser.feed_data(text)
     assert len(messages) == 1
@@ -120,7 +124,7 @@ async def test_parse_body_with_CRLF(parser):
     assert body == b'body'
 
 
-def test_parse_delayed(parser):
+def test_parse_delayed(parser) -> None:
     text = b'GET /test HTTP/1.1\r\n'
     messages, upgrade, tail = parser.feed_data(text)
     assert len(messages) == 0
@@ -132,7 +136,7 @@ def test_parse_delayed(parser):
     assert msg.method == 'GET'
 
 
-def test_headers_multi_feed(parser):
+def test_headers_multi_feed(parser) -> None:
     text1 = b'GET /test HTTP/1.1\r\n'
     text2 = b'test: line\r'
     text3 = b'\n continue\r\n\r\n'
@@ -154,7 +158,7 @@ def test_headers_multi_feed(parser):
     assert not msg.upgrade
 
 
-def test_headers_split_field(parser):
+def test_headers_split_field(parser) -> None:
     text1 = b'GET /test HTTP/1.1\r\n'
     text2 = b't'
     text3 = b'es'
@@ -175,7 +179,7 @@ def test_headers_split_field(parser):
     assert not msg.upgrade
 
 
-def test_parse_headers_multi(parser):
+def test_parse_headers_multi(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'Set-Cookie: c1=cookie1\r\n'
             b'Set-Cookie: c2=cookie2\r\n\r\n')
@@ -192,21 +196,21 @@ def test_parse_headers_multi(parser):
     assert msg.compression is None
 
 
-def test_conn_default_1_0(parser):
+def test_conn_default_1_0(parser) -> None:
     text = b'GET /test HTTP/1.0\r\n\r\n'
     messages, upgrade, tail = parser.feed_data(text)
     msg = messages[0][0]
     assert msg.should_close
 
 
-def test_conn_default_1_1(parser):
+def test_conn_default_1_1(parser) -> None:
     text = b'GET /test HTTP/1.1\r\n\r\n'
     messages, upgrade, tail = parser.feed_data(text)
     msg = messages[0][0]
     assert not msg.should_close
 
 
-def test_conn_close(parser):
+def test_conn_close(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'connection: close\r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -214,7 +218,7 @@ def test_conn_close(parser):
     assert msg.should_close
 
 
-def test_conn_close_1_0(parser):
+def test_conn_close_1_0(parser) -> None:
     text = (b'GET /test HTTP/1.0\r\n'
             b'connection: close\r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -222,7 +226,7 @@ def test_conn_close_1_0(parser):
     assert msg.should_close
 
 
-def test_conn_keep_alive_1_0(parser):
+def test_conn_keep_alive_1_0(parser) -> None:
     text = (b'GET /test HTTP/1.0\r\n'
             b'connection: keep-alive\r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -230,7 +234,7 @@ def test_conn_keep_alive_1_0(parser):
     assert not msg.should_close
 
 
-def test_conn_keep_alive_1_1(parser):
+def test_conn_keep_alive_1_1(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'connection: keep-alive\r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -238,7 +242,7 @@ def test_conn_keep_alive_1_1(parser):
     assert not msg.should_close
 
 
-def test_conn_other_1_0(parser):
+def test_conn_other_1_0(parser) -> None:
     text = (b'GET /test HTTP/1.0\r\n'
             b'connection: test\r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -246,7 +250,7 @@ def test_conn_other_1_0(parser):
     assert msg.should_close
 
 
-def test_conn_other_1_1(parser):
+def test_conn_other_1_1(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'connection: test\r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -254,7 +258,7 @@ def test_conn_other_1_1(parser):
     assert not msg.should_close
 
 
-def test_request_chunked(parser):
+def test_request_chunked(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'transfer-encoding: chunked\r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -264,7 +268,7 @@ def test_request_chunked(parser):
     assert isinstance(payload, streams.StreamReader)
 
 
-def test_conn_upgrade(parser):
+def test_conn_upgrade(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'connection: upgrade\r\n'
             b'upgrade: websocket\r\n\r\n')
@@ -275,7 +279,7 @@ def test_conn_upgrade(parser):
     assert upgrade
 
 
-def test_compression_empty(parser):
+def test_compression_empty(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'content-encoding: \r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -283,7 +287,7 @@ def test_compression_empty(parser):
     assert msg.compression is None
 
 
-def test_compression_deflate(parser):
+def test_compression_deflate(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'content-encoding: deflate\r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -291,7 +295,7 @@ def test_compression_deflate(parser):
     assert msg.compression == 'deflate'
 
 
-def test_compression_gzip(parser):
+def test_compression_gzip(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'content-encoding: gzip\r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -300,7 +304,7 @@ def test_compression_gzip(parser):
 
 
 @pytest.mark.skipif(brotli is None, reason="brotli is not installed")
-def test_compression_brotli(parser):
+def test_compression_brotli(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'content-encoding: br\r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -308,7 +312,7 @@ def test_compression_brotli(parser):
     assert msg.compression == 'br'
 
 
-def test_compression_unknown(parser):
+def test_compression_unknown(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'content-encoding: compress\r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -316,7 +320,7 @@ def test_compression_unknown(parser):
     assert msg.compression is None
 
 
-def test_headers_connect(parser):
+def test_headers_connect(parser) -> None:
     text = (b'CONNECT www.google.com HTTP/1.1\r\n'
             b'content-length: 0\r\n\r\n')
     messages, upgrade, tail = parser.feed_data(text)
@@ -325,7 +329,7 @@ def test_headers_connect(parser):
     assert isinstance(payload, streams.StreamReader)
 
 
-def test_headers_old_websocket_key1(parser):
+def test_headers_old_websocket_key1(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'SEC-WEBSOCKET-KEY1: line\r\n\r\n')
 
@@ -333,7 +337,7 @@ def test_headers_old_websocket_key1(parser):
         parser.feed_data(text)
 
 
-def test_headers_content_length_err_1(parser):
+def test_headers_content_length_err_1(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'content-length: line\r\n\r\n')
 
@@ -341,7 +345,7 @@ def test_headers_content_length_err_1(parser):
         parser.feed_data(text)
 
 
-def test_headers_content_length_err_2(parser):
+def test_headers_content_length_err_2(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'content-length: -1\r\n\r\n')
 
@@ -349,14 +353,14 @@ def test_headers_content_length_err_2(parser):
         parser.feed_data(text)
 
 
-def test_invalid_header(parser):
+def test_invalid_header(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'test line\r\n\r\n')
     with pytest.raises(http_exceptions.BadHttpMessage):
         parser.feed_data(text)
 
 
-def test_invalid_name(parser):
+def test_invalid_name(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'test[]: line\r\n\r\n')
 
@@ -365,17 +369,17 @@ def test_invalid_name(parser):
 
 
 @pytest.mark.parametrize('size', [40960, 8191])
-def test_max_header_field_size(parser, size):
+def test_max_header_field_size(parser, size) -> None:
     name = b't' * size
     text = (b'GET /test HTTP/1.1\r\n' + name + b':data\r\n\r\n')
 
-    match = ("400, message='Got more than 8190 bytes \({}\) when reading"
+    match = ("400, message='Got more than 8190 bytes \\({}\\) when reading"
              .format(size))
     with pytest.raises(http_exceptions.LineTooLong, match=match):
         parser.feed_data(text)
 
 
-def test_max_header_field_size_under_limit(parser):
+def test_max_header_field_size_under_limit(parser) -> None:
     name = b't' * 8190
     text = (b'GET /test HTTP/1.1\r\n' + name + b':data\r\n\r\n')
 
@@ -394,18 +398,18 @@ def test_max_header_field_size_under_limit(parser):
 
 
 @pytest.mark.parametrize('size', [40960, 8191])
-def test_max_header_value_size(parser, size):
+def test_max_header_value_size(parser, size) -> None:
     name = b't' * size
     text = (b'GET /test HTTP/1.1\r\n'
             b'data:' + name + b'\r\n\r\n')
 
-    match = ("400, message='Got more than 8190 bytes \({}\) when reading"
+    match = ("400, message='Got more than 8190 bytes \\({}\\) when reading"
              .format(size))
     with pytest.raises(http_exceptions.LineTooLong, match=match):
         parser.feed_data(text)
 
 
-def test_max_header_value_size_under_limit(parser):
+def test_max_header_value_size_under_limit(parser) -> None:
     value = b'A' * 8190
     text = (b'GET /test HTTP/1.1\r\n'
             b'data:' + value + b'\r\n\r\n')
@@ -425,18 +429,18 @@ def test_max_header_value_size_under_limit(parser):
 
 
 @pytest.mark.parametrize('size', [40965, 8191])
-def test_max_header_value_size_continuation(parser, size):
+def test_max_header_value_size_continuation(parser, size) -> None:
     name = b'T' * (size - 5)
     text = (b'GET /test HTTP/1.1\r\n'
             b'data: test\r\n ' + name + b'\r\n\r\n')
 
-    match = ("400, message='Got more than 8190 bytes \({}\) when reading"
+    match = ("400, message='Got more than 8190 bytes \\({}\\) when reading"
              .format(size))
     with pytest.raises(http_exceptions.LineTooLong, match=match):
         parser.feed_data(text)
 
 
-def test_max_header_value_size_continuation_under_limit(parser):
+def test_max_header_value_size_continuation_under_limit(parser) -> None:
     value = b'A' * 8185
     text = (b'GET /test HTTP/1.1\r\n'
             b'data: test\r\n ' + value + b'\r\n\r\n')
@@ -455,7 +459,7 @@ def test_max_header_value_size_continuation_under_limit(parser):
     assert msg.url == URL('/test')
 
 
-def test_http_request_parser(parser):
+def test_http_request_parser(parser) -> None:
     text = b'GET /path HTTP/1.1\r\n\r\n'
     messages, upgrade, tail = parser.feed_data(text)
     msg = messages[0][0]
@@ -472,13 +476,13 @@ def test_http_request_parser(parser):
     assert msg.url == URL('/path')
 
 
-def test_http_request_bad_status_line(parser):
+def test_http_request_bad_status_line(parser) -> None:
     text = b'getpath \r\n\r\n'
     with pytest.raises(http_exceptions.BadStatusLine):
         parser.feed_data(text)
 
 
-def test_http_request_upgrade(parser):
+def test_http_request_upgrade(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'connection: upgrade\r\n'
             b'upgrade: websocket\r\n\r\n'
@@ -491,7 +495,7 @@ def test_http_request_upgrade(parser):
     assert tail == b'some raw data'
 
 
-def test_http_request_parser_utf8(parser):
+def test_http_request_parser_utf8(parser) -> None:
     text = 'GET /path HTTP/1.1\r\nx-test:тест\r\n\r\n'.encode('utf-8')
     messages, upgrade, tail = parser.feed_data(text)
     msg = messages[0][0]
@@ -508,7 +512,7 @@ def test_http_request_parser_utf8(parser):
     assert msg.url == URL('/path')
 
 
-def test_http_request_parser_non_utf8(parser):
+def test_http_request_parser_non_utf8(parser) -> None:
     text = 'GET /path HTTP/1.1\r\nx-test:тест\r\n\r\n'.encode('cp1251')
     msg = parser.feed_data(text)[0][0][0]
 
@@ -525,7 +529,7 @@ def test_http_request_parser_non_utf8(parser):
     assert msg.url == URL('/path')
 
 
-def test_http_request_parser_two_slashes(parser):
+def test_http_request_parser_two_slashes(parser) -> None:
     text = b'GET //path HTTP/1.1\r\n\r\n'
     msg = parser.feed_data(text)[0][0][0]
 
@@ -538,27 +542,27 @@ def test_http_request_parser_two_slashes(parser):
     assert not msg.chunked
 
 
-def test_http_request_parser_bad_method(parser):
+def test_http_request_parser_bad_method(parser) -> None:
     with pytest.raises(http_exceptions.BadStatusLine):
-        parser.feed_data(b'!12%()+=~$ /get HTTP/1.1\r\n\r\n')
+        parser.feed_data(b'=":<G>(e),[T];?" /get HTTP/1.1\r\n\r\n')
 
 
-def test_http_request_parser_bad_version(parser):
+def test_http_request_parser_bad_version(parser) -> None:
     with pytest.raises(http_exceptions.BadHttpMessage):
         parser.feed_data(b'GET //get HT/11\r\n\r\n')
 
 
 @pytest.mark.parametrize('size', [40965, 8191])
-def test_http_request_max_status_line(parser, size):
+def test_http_request_max_status_line(parser, size) -> None:
     path = b't' * (size - 5)
-    match = ("400, message='Got more than 8190 bytes \({}\) when reading"
+    match = ("400, message='Got more than 8190 bytes \\({}\\) when reading"
              .format(size))
     with pytest.raises(http_exceptions.LineTooLong, match=match):
         parser.feed_data(
             b'GET /path' + path + b' HTTP/1.1\r\n\r\n')
 
 
-def test_http_request_max_status_line_under_limit(parser):
+def test_http_request_max_status_line_under_limit(parser) -> None:
     path = b't' * (8190 - 5)
     messages, upgraded, tail = parser.feed_data(
         b'GET /path' + path + b' HTTP/1.1\r\n\r\n')
@@ -576,7 +580,7 @@ def test_http_request_max_status_line_under_limit(parser):
     assert msg.url == URL('/path' + path.decode())
 
 
-def test_http_response_parser_utf8(response):
+def test_http_response_parser_utf8(response) -> None:
     text = 'HTTP/1.1 200 Ok\r\nx-test:тест\r\n\r\n'.encode('utf-8')
 
     messages, upgraded, tail = response.feed_data(text)
@@ -593,16 +597,16 @@ def test_http_response_parser_utf8(response):
 
 
 @pytest.mark.parametrize('size', [40962, 8191])
-def test_http_response_parser_bad_status_line_too_long(response, size):
+def test_http_response_parser_bad_status_line_too_long(response, size) -> None:
     reason = b't' * (size - 2)
-    match = ("400, message='Got more than 8190 bytes \({}\) when reading"
+    match = ("400, message='Got more than 8190 bytes \\({}\\) when reading"
              .format(size))
     with pytest.raises(http_exceptions.LineTooLong, match=match):
         response.feed_data(
             b'HTTP/1.1 200 Ok' + reason + b'\r\n\r\n')
 
 
-def test_http_response_parser_status_line_under_limit(response):
+def test_http_response_parser_status_line_under_limit(response) -> None:
     reason = b'O' * 8190
     messages, upgraded, tail = response.feed_data(
         b'HTTP/1.1 200 ' + reason + b'\r\n\r\n')
@@ -612,12 +616,12 @@ def test_http_response_parser_status_line_under_limit(response):
     assert msg.reason == reason.decode()
 
 
-def test_http_response_parser_bad_version(response):
+def test_http_response_parser_bad_version(response) -> None:
     with pytest.raises(http_exceptions.BadHttpMessage):
         response.feed_data(b'HT/11 200 Ok\r\n\r\n')
 
 
-def test_http_response_parser_no_reason(response):
+def test_http_response_parser_no_reason(response) -> None:
     msg = response.feed_data(b'HTTP/1.1 200\r\n\r\n')[0][0][0]
 
     assert msg.version == (1, 1)
@@ -625,27 +629,27 @@ def test_http_response_parser_no_reason(response):
     assert not msg.reason
 
 
-def test_http_response_parser_bad(response):
+def test_http_response_parser_bad(response) -> None:
     with pytest.raises(http_exceptions.BadHttpMessage):
         response.feed_data(b'HTT/1\r\n\r\n')
 
 
-def test_http_response_parser_code_under_100(response):
+def test_http_response_parser_code_under_100(response) -> None:
     msg = response.feed_data(b'HTTP/1.1 99 test\r\n\r\n')[0][0][0]
     assert msg.code == 99
 
 
-def test_http_response_parser_code_above_999(response):
+def test_http_response_parser_code_above_999(response) -> None:
     with pytest.raises(http_exceptions.BadHttpMessage):
         response.feed_data(b'HTTP/1.1 9999 test\r\n\r\n')
 
 
-def test_http_response_parser_code_not_int(response):
+def test_http_response_parser_code_not_int(response) -> None:
     with pytest.raises(http_exceptions.BadHttpMessage):
         response.feed_data(b'HTTP/1.1 ttt test\r\n\r\n')
 
 
-def test_http_request_chunked_payload(parser):
+def test_http_request_chunked_payload(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'transfer-encoding: chunked\r\n\r\n')
     msg, payload = parser.feed_data(text)[0][0]
@@ -661,7 +665,7 @@ def test_http_request_chunked_payload(parser):
     assert payload.is_eof()
 
 
-def test_http_request_chunked_payload_and_next_message(parser):
+def test_http_request_chunked_payload_and_next_message(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'transfer-encoding: chunked\r\n\r\n')
     msg, payload = parser.feed_data(text)[0][0]
@@ -683,7 +687,7 @@ def test_http_request_chunked_payload_and_next_message(parser):
     assert not payload2.is_eof()
 
 
-def test_http_request_chunked_payload_chunks(parser):
+def test_http_request_chunked_payload_chunks(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'transfer-encoding: chunked\r\n\r\n')
     msg, payload = parser.feed_data(text)[0][0]
@@ -706,7 +710,7 @@ def test_http_request_chunked_payload_chunks(parser):
     assert payload.is_eof()
 
 
-def test_parse_chunked_payload_chunk_extension(parser):
+def test_parse_chunked_payload_chunk_extension(parser) -> None:
     text = (b'GET /test HTTP/1.1\r\n'
             b'transfer-encoding: chunked\r\n\r\n')
     msg, payload = parser.feed_data(text)[0][0]
@@ -727,7 +731,8 @@ def _test_parse_no_length_or_te_on_post(loop, protocol, request_cls):
     assert payload.is_eof()
 
 
-def test_parse_payload_response_without_body(loop, protocol, response_cls):
+def test_parse_payload_response_without_body(loop, protocol,
+                                             response_cls) -> None:
     parser = response_cls(protocol, loop, response_with_body=False)
     text = (b'HTTP/1.1 200 Ok\r\n'
             b'content-length: 10\r\n\r\n')
@@ -736,7 +741,7 @@ def test_parse_payload_response_without_body(loop, protocol, response_cls):
     assert payload.is_eof()
 
 
-def test_parse_length_payload(response):
+def test_parse_length_payload(response) -> None:
     text = (b'HTTP/1.1 200 Ok\r\n'
             b'content-length: 4\r\n\r\n')
     msg, payload = response.feed_data(text)[0][0]
@@ -750,13 +755,13 @@ def test_parse_length_payload(response):
     assert b'data' == b''.join(d for d in payload._buffer)
 
 
-def test_parse_no_length_payload(parser):
+def test_parse_no_length_payload(parser) -> None:
     text = b'PUT / HTTP/1.1\r\n\r\n'
     msg, payload = parser.feed_data(text)[0][0]
     assert payload.is_eof()
 
 
-def test_partial_url(parser):
+def test_partial_url(parser) -> None:
     messages, upgrade, tail = parser.feed_data(b'GET /te')
     assert len(messages) == 0
     messages, upgrade, tail = parser.feed_data(b'st HTTP/1.1\r\n\r\n')
@@ -770,7 +775,7 @@ def test_partial_url(parser):
     assert payload.is_eof()
 
 
-def test_url_parse_non_strict_mode(parser):
+def test_url_parse_non_strict_mode(parser) -> None:
     payload = 'GET /test/тест HTTP/1.1\r\n\r\n'.encode('utf-8')
     messages, upgrade, tail = parser.feed_data(payload)
     assert len(messages) == 1
@@ -785,8 +790,9 @@ def test_url_parse_non_strict_mode(parser):
 
 class TestParsePayload:
 
-    def test_parse_eof_payload(self, stream):
-        out = aiohttp.FlowControlDataQueue(stream)
+    async def test_parse_eof_payload(self, stream) -> None:
+        out = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         p = HttpPayloadParser(out, readall=True)
         p.feed_data(b'data')
         p.feed_eof()
@@ -794,15 +800,17 @@ class TestParsePayload:
         assert out.is_eof()
         assert [(bytearray(b'data'), 4)] == list(out._buffer)
 
-    def test_parse_no_body(self, stream):
-        out = aiohttp.FlowControlDataQueue(stream)
+    async def test_parse_no_body(self, stream) -> None:
+        out = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         p = HttpPayloadParser(out, method='PUT')
 
         assert out.is_eof()
         assert p.done
 
-    def test_parse_length_payload_eof(self, stream):
-        out = aiohttp.FlowControlDataQueue(stream)
+    async def test_parse_length_payload_eof(self, stream) -> None:
+        out = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
 
         p = HttpPayloadParser(out, length=4)
         p.feed_data(b'da')
@@ -810,16 +818,18 @@ class TestParsePayload:
         with pytest.raises(http_exceptions.ContentLengthError):
             p.feed_eof()
 
-    def test_parse_chunked_payload_size_error(self, stream):
-        out = aiohttp.FlowControlDataQueue(stream)
+    async def test_parse_chunked_payload_size_error(self, stream) -> None:
+        out = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         p = HttpPayloadParser(out, chunked=True)
         with pytest.raises(http_exceptions.TransferEncodingError):
             p.feed_data(b'blah\r\n')
         assert isinstance(out.exception(),
                           http_exceptions.TransferEncodingError)
 
-    def test_http_payload_parser_length(self, stream):
-        out = aiohttp.FlowControlDataQueue(stream)
+    async def test_http_payload_parser_length(self, stream) -> None:
+        out = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         p = HttpPayloadParser(out, length=2)
         eof, tail = p.feed_data(b'1245')
         assert eof
@@ -830,37 +840,41 @@ class TestParsePayload:
     _comp = zlib.compressobj(wbits=-zlib.MAX_WBITS)
     _COMPRESSED = b''.join([_comp.compress(b'data'), _comp.flush()])
 
-    def test_http_payload_parser_deflate(self, stream):
+    async def test_http_payload_parser_deflate(self, stream) -> None:
         length = len(self._COMPRESSED)
-        out = aiohttp.FlowControlDataQueue(stream)
+        out = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         p = HttpPayloadParser(
             out, length=length, compression='deflate')
         p.feed_data(self._COMPRESSED)
         assert b'data' == b''.join(d for d, _ in out._buffer)
         assert out.is_eof()
 
-    def test_http_payload_parser_deflate_no_wbits(self, stream):
+    async def test_http_payload_parser_deflate_no_wbits(self, stream) -> None:
         comp = zlib.compressobj()
         COMPRESSED = b''.join([comp.compress(b'data'), comp.flush()])
 
         length = len(COMPRESSED)
-        out = aiohttp.FlowControlDataQueue(stream)
+        out = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         p = HttpPayloadParser(
             out, length=length, compression='deflate')
         p.feed_data(COMPRESSED)
         assert b'data' == b''.join(d for d, _ in out._buffer)
         assert out.is_eof()
 
-    def test_http_payload_parser_length_zero(self, stream):
-        out = aiohttp.FlowControlDataQueue(stream)
+    async def test_http_payload_parser_length_zero(self, stream) -> None:
+        out = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         p = HttpPayloadParser(out, length=0)
         assert p.done
         assert out.is_eof()
 
     @pytest.mark.skipif(brotli is None, reason="brotli is not installed")
-    def test_http_payload_brotli(self, stream):
+    async def test_http_payload_brotli(self, stream) -> None:
         compressed = brotli.compress(b'brotli data')
-        out = aiohttp.FlowControlDataQueue(stream)
+        out = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         p = HttpPayloadParser(
             out, length=len(compressed), compression='br')
         p.feed_data(compressed)
@@ -870,8 +884,9 @@ class TestParsePayload:
 
 class TestDeflateBuffer:
 
-    def test_feed_data(self, stream):
-        buf = aiohttp.FlowControlDataQueue(stream)
+    async def test_feed_data(self, stream) -> None:
+        buf = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         dbuf = DeflateBuffer(buf, 'deflate')
 
         dbuf.decompressor = mock.Mock()
@@ -880,8 +895,9 @@ class TestDeflateBuffer:
         dbuf.feed_data(b'data', 4)
         assert [b'line'] == list(d for d, _ in buf._buffer)
 
-    def test_feed_data_err(self, stream):
-        buf = aiohttp.FlowControlDataQueue(stream)
+    async def test_feed_data_err(self, stream) -> None:
+        buf = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         dbuf = DeflateBuffer(buf, 'deflate')
 
         exc = ValueError()
@@ -891,8 +907,9 @@ class TestDeflateBuffer:
         with pytest.raises(http_exceptions.ContentEncodingError):
             dbuf.feed_data(b'data', 4)
 
-    def test_feed_eof(self, stream):
-        buf = aiohttp.FlowControlDataQueue(stream)
+    async def test_feed_eof(self, stream) -> None:
+        buf = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         dbuf = DeflateBuffer(buf, 'deflate')
 
         dbuf.decompressor = mock.Mock()
@@ -902,8 +919,9 @@ class TestDeflateBuffer:
         assert [b'line'] == list(d for d, _ in buf._buffer)
         assert buf._eof
 
-    def test_feed_eof_err_deflate(self, stream):
-        buf = aiohttp.FlowControlDataQueue(stream)
+    async def test_feed_eof_err_deflate(self, stream) -> None:
+        buf = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         dbuf = DeflateBuffer(buf, 'deflate')
 
         dbuf.decompressor = mock.Mock()
@@ -913,8 +931,9 @@ class TestDeflateBuffer:
         with pytest.raises(http_exceptions.ContentEncodingError):
             dbuf.feed_eof()
 
-    def test_feed_eof_no_err_gzip(self, stream):
-        buf = aiohttp.FlowControlDataQueue(stream)
+    async def test_feed_eof_no_err_gzip(self, stream) -> None:
+        buf = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         dbuf = DeflateBuffer(buf, 'gzip')
 
         dbuf.decompressor = mock.Mock()
@@ -924,8 +943,9 @@ class TestDeflateBuffer:
         dbuf.feed_eof()
         assert [b'line'] == list(d for d, _ in buf._buffer)
 
-    def test_feed_eof_no_err_brotli(self, stream):
-        buf = aiohttp.FlowControlDataQueue(stream)
+    async def test_feed_eof_no_err_brotli(self, stream) -> None:
+        buf = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         dbuf = DeflateBuffer(buf, 'br')
 
         dbuf.decompressor = mock.Mock()
@@ -935,8 +955,9 @@ class TestDeflateBuffer:
         dbuf.feed_eof()
         assert [b'line'] == list(d for d, _ in buf._buffer)
 
-    def test_empty_body(self, stream):
-        buf = aiohttp.FlowControlDataQueue(stream)
+    async def test_empty_body(self, stream) -> None:
+        buf = aiohttp.FlowControlDataQueue(stream,
+                                           loop=asyncio.get_event_loop())
         dbuf = DeflateBuffer(buf, 'deflate')
         dbuf.feed_eof()
 
